/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.client

import android.content.Context
import com.kakao.sdk.partner.friend.RxFriendPickerManager
import com.kakao.sdk.partner.friend.model.PickerFriendRequestParams
import com.kakao.sdk.partner.friend.model.SelectedUsers
import io.reactivex.Single

class RxPickerClient {

    /**
     * 화면 전체에 표시되는 멀티 친구 선택 화면 띄우기
     */
    fun selectFriends(
        context: Context,
        params: PickerFriendRequestParams) : Single<SelectedUsers>
    = RxFriendPickerManager().startActivity(context, params)

    /**
     * 화면 전체에 표시되는 싱글 친구 선택 화면 띄우기
     */
    fun selectFriend(
        context: Context,
        params: PickerFriendRequestParams
    ) = RxFriendPickerManager().startActivity(context, params, isSingle = true)

    /**
     * 팝업 형태로 표시되는 멀티 친구 선택 화면 띄우기
     */
    fun selectFriendsPopup(
        context: Context,
        params: PickerFriendRequestParams
    ) = RxFriendPickerManager().startActivity(context, params, isPopup = true)

    /**
     * 팝업 형태로 표시되는 싱글 친구 선택 화면 띄우기
     */
    fun selectFriendPopup(
        context: Context,
        params: PickerFriendRequestParams
    ) = RxFriendPickerManager().startActivity(context, params, isSingle = true, isPopup = true)

    companion object {
        /**
         * 간편한 API 호출을 위해 기본 제공되는 singleton 객체
         */
        @JvmStatic
        val instance by lazy { PickerClient.rx }
    }
}

val PickerClient.Companion.rx by lazy { RxPickerClient() }