/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.util

import java.text.BreakIterator

/**
 * @suppress
 */
internal object StringUtils {
    private const val MVS = '\u180e'            // Mongolian Vowel Separator
    private const val ZWSP = '\u200b'           // Zero-width Space
    private const val ZWNJ = '\u200c'           // Zero-width Non-joiner
    private const val ZWJ = '\u200d'            // Zero-width Joiner
    private const val WJ = '\u2060'             // Word Joiner
    private val ZERO_WIDTH_CHARS = charArrayOf(MVS, ZWSP, ZWNJ, ZWJ, WJ)

    fun String.trimZeroWidthChars(): String = trim(*ZERO_WIDTH_CHARS)

    // 이모지를 한글자로 처리해서 글자수 세기
    fun String.graphemeLength(): Int {
        val it = BreakIterator.getCharacterInstance()
        it.setText(this)
        var count = 0
        while (it.next() != BreakIterator.DONE) {
            count++
        }
        return count
    }

    // String 한글자씩 분리
    fun String.getParsedString(): List<String> {
        val it = BreakIterator.getCharacterInstance()
        it.setText(this)
        val strings = mutableListOf(String(Character.toChars(this.codePointAt(it.current()))))
        while (it.next() != BreakIterator.DONE && it.current() < this.length) {
            strings.add(String(Character.toChars(this.codePointAt(it.current()))))
        }
        return strings
    }
}