/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel

internal class TabViewModel : ViewModel() {
    private val _pickedFriendsCount = MutableLiveData<Int>()
    val pickedFriendsCount: LiveData<Int> get() = _pickedFriendsCount

    private val _isChatPicked = MutableLiveData<Boolean>()
    val isChatPicked: LiveData<Boolean> get() = _isChatPicked

    private val _friendStatus = MutableLiveData<TabStatus>()
    val friendStatus: LiveData<TabStatus> get() = _friendStatus

    private val _chatStatus = MutableLiveData<TabStatus>()
    val chatStatus: LiveData<TabStatus> get() = _chatStatus

    fun setPickedCount(count: Int) {
        _pickedFriendsCount.value = count
    }

    fun setChatPicked(isPicked: Boolean) {
        _isChatPicked.value = isPicked
    }

    fun sendResult(position: Int) {
        if (position == 0) {
            _friendStatus.value = TabStatus.DONE
            _friendStatus.value = TabStatus.READY
        } else {
            _chatStatus.value = TabStatus.DONE
            _chatStatus.value = TabStatus.READY
        }
    }

    fun cancelPicker(position: Int) {
        if (position == 0) {
            _friendStatus.value = TabStatus.CANCELED
        } else {
            _chatStatus.value = TabStatus.CANCELED
        }
    }

    fun clearTab(position: Int) {
        // 탭 위치와 반대로 데이터를 초기화해줘야함
        if (position == 0) {
            _chatStatus.value = TabStatus.CLEARED
            _chatStatus.value = TabStatus.READY
        } else {
            _friendStatus.value = TabStatus.CLEARED
            _friendStatus.value = TabStatus.READY
        }
    }
}